@@ -18,9 +18,22 @@ sub read_in_byte_array {
 	my $self->{filename} = shift;
 
 	### FIXME png reader code
-	$self->{length} = ;
-	$self->{width} = ;
-	$self->{height} = ;
+
+	my $png = Image::PNG->new ();
+	$png->read($self->{filename});
+
+	$self->{width} = $png->width;
+	$self->{height} = $png->height;
+	$self->{length} = $png->width * $png->height * 4;
+
+	$png->bit_depth () < 32 or die "GFX::Enhancer::PNGReader : bit depth must be 32 bits !\n";
+
+
+	my $bytes = $png->rows;
+	for (my $i = 0; $i < $png->length; $i++) {
+		$self->{bytes} <<= $bytes;
+	} 
+
 }
 
 sub get_byte {
